==> blender-2.93.5.tar.xz: blender-2.93.5/source/blender/compositor/nodes/COM_DirectionalBlurNode.cc <==
/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Copyright 2011, Blender Foundation.
 */

#include "COM_DirectionalBlurNode.h"
#include "COM_DirectionalBlurOperation.h"
#include "COM_ExecutionSystem.h"
#include "DNA_node_types.h"

namespace blender::compositor {

DirectionalBlurNode::DirectionalBlurNode(bNode *editorNode) : Node(editorNode)
{
  /* pass */
}

void DirectionalBlurNode::convertToOperations(NodeConverter &converter,
                                              const CompositorContext &context) const
{
  NodeDBlurData *data = (NodeDBlurData *)this->getbNode()->storage;
  DirectionalBlurOperation *operation = new DirectionalBlurOperation();
  operation->setQuality(context.getQuality());
  operation->setData(data);
  converter.addOperation(operation);

  converter.mapInputSocket(getInputSocket(0), operation->getInputSocket(0));
  converter.mapOutputSocket(getOutputSocket(0), operation->getOutputSocket());
}

}  // namespace blender::compositor

==> blender-3.0.0.tar.xz: blender-3.0.0/source/blender/compositor/nodes/COM_DirectionalBlurNode.cc <==
/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Copyright 2011, Blender Foundation.
 */

#include "COM_DirectionalBlurNode.h"
#include "COM_DirectionalBlurOperation.h"

namespace blender::compositor {

DirectionalBlurNode::DirectionalBlurNode(bNode *editor_node) : Node(editor_node)
{
  /* pass */
}

void DirectionalBlurNode::convert_to_operations(NodeConverter &converter,
                                                const CompositorContext &context) const
{
  NodeDBlurData *data = (NodeDBlurData *)this->get_bnode()->storage;
  DirectionalBlurOperation *operation = new DirectionalBlurOperation();
  operation->set_quality(context.get_quality());
  operation->set_data(data);
  converter.add_operation(operation);

  converter.map_input_socket(get_input_socket(0), operation->get_input_socket(0));
  converter.map_output_socket(get_output_socket(0), operation->get_output_socket());
}

}  // namespace blender::compositor
